@@ -1,4 +1,4 @@
-# Copyright (C) 2009 by the Free Software Foundation, Inc.
+# Copyright (C) 2009, 2010 by Barry A. Warsaw
 #
 # This file is part of flufl.i18n
 #
@@ -16,9 +16,20 @@
 
 """Expose sub-module names in the package namespace."""
 
-__version__ = '0.4'
+__version__ = '0.5'
 
 from flufl.i18n._expand import expand
 from flufl.i18n._registry import registry
 # pylint: disable-msg=W0401
 from flufl.i18n._strategy import *
+
+
+def initialize(domain):
+    """A convenience function for setting up translation.
+
+    :param domain: The application's name.
+    :type domain: string
+    """
+    strategy = SimpleStrategy(domain)
+    application = registry.register(strategy)
+    return application._
