@@ -1,4 +1,4 @@
-# Copyright (C) 2009 by the Free Software Foundation, Inc.
+# Copyright (C) 2009, 2010 by Barry A. Warsaw
 #
 # This file is part of flufl.i18n
 #
@@ -169,6 +169,7 @@ class Application:
         # public API so that we share code.
         self._default_language = None
         self._default_translator = None
+        # This sets the _default_translator.
         del self.default
 
     @property
@@ -207,7 +208,7 @@ class Application:
         """Reset the default language to the null translator."""
         self._default_language = None
         self._default_translator = Translator(
-            gettext.NullTranslations(), self.dedent, self.depth)
+            self._strategy(), self.dedent, self.depth)
 
     def get(self, language_code):
         """Get the catalog associated with the language code.
